from datetime import datetime
from typing import Optional

from pydantic import BaseModel, EmailStr


# Shared properties
class SupplierBase(BaseModel):
    name: Optional[str] = None
    contact_name: Optional[str] = None
    email: Optional[EmailStr] = None
    phone: Optional[str] = None
    address: Optional[str] = None


# Properties to receive via API on creation
class SupplierCreate(SupplierBase):
    name: str


# Properties to receive via API on update
class SupplierUpdate(SupplierBase):
    pass


# Properties to return via API
class SupplierInDB(SupplierBase):
    id: str
    name: str
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True


# Additional properties to return via API
class Supplier(SupplierInDB):
    pass
